@@ -17,6 +17,8 @@ from __future__ import annotations
 import re
 import warnings
 import importlib
+import inspect
+import functools
 from types import ModuleType
 from functools import wraps
 from typing import (
@@ -30,19 +32,14 @@ from typing import (
     Container,
     Mapping,
     NamedTuple,
-    NoReturn,
     MutableMapping,
     Collection,
     cast,
-    overload
+    overload,
 )
 
+from .typing_utils import Literal
 from .empty import EMPTY_CONTAINER
-from ._partial import PartialPrepend
-from ._set_attr import SetAttr
-from ._seq_view import SequenceView
-from ._catch_err import CatchErrors
-from ._lazy_import import LazyImporter, MutableLazyImporter
 
 __all__ = [
     'PartialPrepend',
@@ -60,6 +57,10 @@ __all__ = [
     'CatchErrors',
     'LazyImporter',
     'MutableLazyImporter',
+    'positional_only',
+    'UserMapping',
+    'MutableUserMapping',
+    'warning_filter',
 ]
 
 _T = TypeVar('_T')
@@ -367,13 +368,7 @@ def _disgard_keys(
             return set(dct.keys()).intersection(keep_keys)
 
 
-@overload
-def raise_if(exception: None) -> Callable[[_FT], _FT]:
-    ...
-@overload  # noqa: E302
-def raise_if(exception: BaseException) -> Callable[[Callable[..., Any]], Callable[..., NoReturn]]:
-    ...
-def raise_if(exception):  # noqa: E302
+def raise_if(exception: None | BaseException) -> Callable[[_FT], _FT]:
     """A decorator which raises the passed exception whenever calling the decorated function.
 
     If **exception** is :data:`None` then the decorated function will be called as usual.
@@ -422,24 +417,18 @@ def raise_if(exception):  # noqa: E302
         return decorator1
 
     elif isinstance(exception, BaseException):
-        def decorator2(func: Callable[..., Any]) -> Callable[..., NoReturn]:
+        def decorator2(func: _FT) -> _FT:
             @wraps(func)
-            def wrapper(*args: Any, **kwargs: Any) -> NoReturn:
+            def wrapper(*args, **kwargs):
                 raise exception
-            return wrapper
+            return wrapper  # type: ignore[return-value]
         return decorator2
 
     else:
         raise TypeError(f"{exception.__class__.__name__!r}")
 
 
-@overload
-def ignore_if(exception: None, warn: bool = ...) -> Callable[[_FT], _FT]:
-    ...
-@overload  # noqa: E302
-def ignore_if(exception: BaseException, warn: bool = ...) -> Callable[[Callable[..., Any]], Callable[..., None]]:  # noqa: E501
-    ...
-def ignore_if(exception, warn=True):  # noqa: E302
+def ignore_if(exception: None | BaseException, warn: bool = True) -> Callable[[_FT], _FT]:
     """A decorator which, if an exception is passed, ignores calls to the decorated function.
 
     If **exception** is :data:`None` then the decorated function will be called as usual.
@@ -497,7 +486,7 @@ def ignore_if(exception, warn=True):  # noqa: E302
         return decorator1
 
     elif isinstance(exception, BaseException):
-        def decorator2(func: Callable[..., Any]) -> Callable[..., None]:
+        def decorator2(func: _FT) -> _FT:
             msg = f"Skipping call to {get_func_name(func)}()"
 
             @wraps(func)
@@ -507,7 +496,7 @@ def ignore_if(exception, warn=True):  # noqa: E302
                     exc.__cause__ = exception
                     warnings.warn(exc)
                     return None
-            return wrapper
+            return wrapper  # type: ignore[return-value]
         return decorator2
 
     else:
@@ -683,4 +672,152 @@ def _null_func(obj: _T) -> _T:
     return obj
 
 
-__doc__ = construct_api_doc(globals(), decorators={'set_docstring', 'raise_if', 'ignore_if'})
+def positional_only(func: _FT) -> _FT:
+    """A decorator for converting mangled parameters to positional-only.
+
+    Sets the ``__signature__`` attribute of the decorated function.
+
+    Examples
+    --------
+    .. code-block:: python
+
+        >>> from nanoutils import positional_only
+        >>> import inspect
+
+        >>> def func1(__a, b=None):
+        ...     pass
+
+        >>> print(inspect.signature(func1))
+        (__a, b=None)
+
+        >>> @positional_only
+        ... def func2(__a, b=None):
+        ...     pass
+
+        >>> print(inspect.signature(func2))
+        (a, /, b=None)
+
+    Parameters
+    ----------
+    func : :class:`~collections.abc.Callable`
+        The to-be decorated function whose ``__signature__`` attribute will be added or updated.
+
+    """
+    # Check if any name mangling has occured
+    cls_name, period, _ = getattr(func, "__qualname__", "").partition(".")
+    prefix = "__" if not period else f"_{cls_name}__"
+    offset = len(prefix)
+
+    # Identify the if `__`-prefixed parameters
+    sgn = inspect.signature(func)
+    pos_only_list = []
+    for j, name in enumerate(sgn.parameters):
+        if name.startswith(prefix):
+            pos_only_list.append(j)
+
+    if not pos_only_list:
+        func.__signature__ = sgn  # type: ignore[attr-defined]
+        return func
+    else:
+        j = pos_only_list[-1]
+
+    # Unmangle parameters and convert them to positional-only
+    prm_list = []
+    for i, (name, prm) in enumerate(sgn.parameters.items()):
+        if i <= j:
+            if name.startswith(prefix):
+                name = name[offset:]
+            prm = prm.replace(name=name, kind=inspect.Parameter.POSITIONAL_ONLY)
+        prm_list.append(prm)
+
+    func.__signature__ = inspect.Signature(   # type: ignore[attr-defined]
+        parameters=prm_list,
+        return_annotation=sgn.return_annotation,
+    )
+    func.__annotations__ = {
+        (k[offset:] if k.startswith(prefix) else k): v for k, v in func.__annotations__.items()
+    }
+    return func
+
+
+def warning_filter(
+    action: Literal["default", "error", "ignore", "always", "module", "once"],
+    message: str = "",
+    category: type[Warning] = Warning,
+    module: str = "",
+    lineno: int = 0,
+    append: bool = False,
+) -> Callable[[_FT], _FT]:
+    """A decorator for wrapping function calls with :func:`warnings.filterwarnings`.
+
+    Examples
+    --------
+    .. code-block:: python
+
+        >>> from nanoutils import warning_filter
+        >>> import warnings
+
+        >>> @warning_filter("error", category=UserWarning)
+        ... def func():
+        ...     warnings.warn("test", UserWarning)
+
+        >>> func()
+        Traceback (most recent call last):
+            ...
+        UserWarning: test
+
+    Parameters
+    ----------
+    action : :class:`str`
+        One of the following strings:
+
+        * ``"default"``: Print the first occurrence of matching warnings for each location (module + line number) where the warning is issued
+        * ``"error"``: Turn matching warnings into exceptions
+        * ``"ignore"``: Never print matching warnings
+        * ``"always"``: Always print matching warnings
+        * ``"module"``: Print the first occurrence of matching warnings for each module where the warning is issued (regardless of line number)
+        * ``"once"``: Print only the first occurrence of matching warnings, regardless of location
+
+    message : :class:`str`, optional
+        A string containing a regular expression that the start of the warning message must match.
+        The expression is compiled to always be case-insensitive.
+    category : :class:`type[Warning] <type>`
+        The to-be affected :class:`Warning` (sub-)class.
+    module : :class:`str`, optional
+        A string containing a regular expression that the module name must match.
+        The expression is compiled to be case-sensitive.
+    lineno : :class:`int`
+        An integer that the line number where the warning occurred must match,
+        or 0 to match all line numbers.
+    append : :class:`bool`
+        Whether the warning entry is inserted at the end.
+
+    See Also
+    --------
+    :func:`warnings.filterwarnings` :
+        Insert a simple entry into the list of warnings filters (at the front).
+
+    """
+    def decorator(func: _FT) -> _FT:
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            with warnings.catch_warnings():
+                warnings.filterwarnings(action, message, category, module, lineno, append)
+                ret = func(*args, **kwargs)
+            return ret
+        return cast(_FT, wrapper)
+    return decorator
+
+
+# Move to the end to reduce the risk of circular imports
+from ._partial import PartialPrepend
+from ._set_attr import SetAttr
+from ._seq_view import SequenceView
+from ._catch_err import CatchErrors
+from ._lazy_import import LazyImporter, MutableLazyImporter
+from ._user_dict import UserMapping, MutableUserMapping
+
+__doc__ = construct_api_doc(
+    globals(),
+    decorators={'set_docstring', 'raise_if', 'ignore_if', 'positional_only', 'warning_filter'},
+)
